EasyEnsembleClassifier
================================================================================

.. currentmodule:: imbalanced_ensemble.ensemble.under_sampling

.. autoclass:: EasyEnsembleClassifier

   

   
   .. rubric:: Methods

   .. autosummary::
   
      
      
        ~EasyEnsembleClassifier.decision_function
      
      
        ~EasyEnsembleClassifier.fit
      
      
        ~EasyEnsembleClassifier.get_params
      
      
        ~EasyEnsembleClassifier.predict
      
      
        ~EasyEnsembleClassifier.predict_log_proba
      
      
        ~EasyEnsembleClassifier.predict_proba
      
      
        ~EasyEnsembleClassifier.score
      
      
        ~EasyEnsembleClassifier.set_params
      
   
   

.. include:: ../../../back_references/imbalanced_ensemble.ensemble.under_sampling.EasyEnsembleClassifier.examples

.. raw:: html

    <div style='clear:both'></div>